@@ -33,6 +33,9 @@ vcovBS.lm <- function(x, cluster = NULL, R = 250, type = "xy", ..., fix = FALSE,
   
   if(NROW(cluster) != n) stop("number of observations in 'cluster' and 'nobs()' do not match")
 
+  ## catch NAs in cluster -> need to be addressed in the model object by the user
+  if(anyNA(cluster)) stop("cannot handle NAs in 'cluster': either refit the model without the NA observations in 'cluster' or impute the NAs")
+
   ## for multi-way clustering: set up interaction patterns
   p <- NCOL(cluster)
   if (p > 1L) {
@@ -178,6 +181,9 @@ vcovBS.glm <- function(x, cluster = NULL, R = 250, start = FALSE, ..., fix = FAL
   
   if(NROW(cluster) != n) stop("number of observations in 'cluster' and 'nobs()' do not match")
 
+  ## catch NAs in cluster -> need to be addressed in the model object by the user
+  if(anyNA(cluster)) stop("cannot handle NAs in 'cluster': either refit the model without the NA observations in 'cluster' or impute the NAs")
+
   ## for multi-way clustering: set up interaction patterns
   p <- NCOL(cluster)
   if (p > 1L) {
